==> pure-ftpd-1.0.29.tar.bz2: pure-ftpd-1.0.29/src/messages_zh_cn.h <==
#define MSG_TIMEOUT "ʱ"
#define MSG_CAPABILITIES "޷л"
#define MSG_CLIENT_CLOSED_CNX "û˹ر"
#define MSG_CLIENT_READ_ERR "û˶ȡ"
#define MSG_CANT_OPEN_CNX "޷"
#define MSG_CANT_CREATE_DATA_SOCKET "޷ݽӿ"
#define MSG_DEBUG_CLIENT_IS "û˵ַ"
#define MSG_SYNTAX_ERROR_IP "﷨IPַ"
#define MSG_PORT_SUCCESSFUL "PORTOK"
#define MSG_ONLY_IPV4V6 "֧IPv4IPv6 (1,2)"
#define MSG_ONLY_IPV4 "֧IPv4 (1)"
#define MSG_TIMEOUT_PARSER "ʱ - »üʱٶȿһ"
#define MSG_LINE_TOO_LONG "й"
#define MSG_LOG_OVERFLOW "ûҪл"
#define MSG_GOODBYE "ټϴ%llu%llu kbytes."
#define MSG_DEBUG_COMMAND ""
#define MSG_IS_YOUR_CURRENT_LOCATION "Ŀǰλ"
#define MSG_NOT_LOGGED_IN "δ¼"
#define MSG_AUTH_UNIMPLEMENTED "ȫδʵʩ"
#define MSG_NO_FILE_NAME "ļ"
#define MSG_NO_DIRECTORY_NAME "Ŀ¼"
#define MSG_NO_RESTART_POINT "¿ʼ"
#define MSG_ABOR_SUCCESS "ABOR OK"
#define MSG_MISSING_ARG "ȱٲ"
#define MSG_GARBAGE_FOUND "ֵõִ"
#define MSG_VALUE_TOO_LARGE "ֵ"
#define MSG_IDLE_TIME "ʱΪ %lu "
#define MSG_SITE_HELP "еSITEϿ"
#define MSG_BAD_CHMOD "ЧȨ"
#define MSG_UNKNOWN_EXTENSION "δ֪"
#define MSG_XDBG_OK "XDBGOKԼ %d"
#define MSG_UNKNOWN_COMMAND "δ֪"
#define MSG_TIMEOUT_NOOP "ʱ ( %lu ޲)"
#define MSG_TIMEOUT_DATA "ʱ ( %lu )"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Ѿ¼"
#define MSG_ANY_PASSWORD "κ붼"
#define MSG_ANONYMOUS_LOGGED "ʹߵ¼"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "ʹߵ¼FTP"
#define MSG_USER_OK "ʹ %s OK. Ҫ."
#define MSG_CANT_DO_TWICE "Ŀǰڼ䲻"
#define MSG_UNABLE_SECURE_ANON "޷ȫFTP"
#define MSG_BANDWIDTH_RESTRICTED "Ĵʹ"
#define MSG_NO_PASSWORD_NEEDED "κ붼"
#define MSG_NOTRUST "Ǹ޷"
#define MSG_WHOAREYOU "˭"
#define MSG_AUTH_FAILED "֤ʧܣǸ"
#define MSG_AUTH_TOOMANY "֤ʧ̫"
#define MSG_NO_HOMEDIR "ûмĿ¼ - ȡ"
#define MSG_NO_HOMEDIR2 "%s ڻ޷"
#define MSG_START_SLASH "ʼ /"
#define MSG_USER_GROUP_ACCESS "ʹ %s Ȩޣ"
#define MSG_FXP_SUPPORT "֧FXP"
#define MSG_RATIO " %u:%u (UL/DL) "
#define MSG_CHROOT_FAILED "޷趨ȫchroot() jail"
#define MSG_CURRENT_DIR_IS "OK. ĿǰĿ¼ %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. ĿǰƵĿ¼ %s"
#define MSG_IS_NOW_LOGGED_IN "%s ڵ¼"
#define MSG_CANT_CHANGE_DIR "޷Ŀ¼ %s"
#define MSG_PATH_TOO_LONG "·̫"
#define MSG_CANT_PASV "IPv6ʹPASVEPSV"
#define MSG_CANT_PASSIVE "޷ʽ"
#define MSG_PORTS_BUSY "бTCP portsæµ"
#define MSG_GETSOCKNAME_DATA "޷ʶ𱾻ݽӿ"
#define MSG_GETPEERNAME "޷ʶ𱾻ӿ"
#define MSG_INVALID_IP "ǸЧĵַ"
#define MSG_NO_EPSV "ʹ÷IPv6֧EPSVû"
#define MSG_BAD_PORT "Ǹ޷ӵ ports < 1024"
#define MSG_NO_FXP "Ҳܿӵ %s ( %s)"
#define MSG_FXP "FXP:  %s  %s"
#define MSG_NO_DATA_CONN ""
#define MSG_ACCEPT_FAILED "޷"
#define MSG_ACCEPT_SUCCESS ""
#define MSG_CNX_PORT_FAILED "޷ӵport %d"
#define MSG_CNX_PORT "ӵport %d"
#define MSG_ANON_CANT_MKD "Ǹ׼ʹ߽Ŀ¼"
#define MSG_ANON_CANT_RMD "Ǹ׼ʹɾĿ¼"
#define MSG_ANON_CANT_RENAME "׼ʹƶ/ļ"
#define MSG_ANON_CANT_CHANGE_PERMS "ʹ߲ܱȨ"
#define MSG_GLOB_NO_MEMORY "γ %s ʱڴ治"
#define MSG_PROBABLY_DENIED "(ζ \"ܾ\")"
#define MSG_GLOB_READ_ERROR "γ %s ʱȡ"
#define MSG_GLOB_NO_MATCH "ûзϵ %s  %s "
#define MSG_CHMOD_FAILED "ܱ %s Ȩ"
#define MSG_CHMOD_SUCCESS " %s Ȩѱ"
#define MSG_CHMOD_TOTAL_FAILURE "Ǹ޷κȨ"
#define MSG_ANON_CANT_DELETE "ʹ߲ɾļ"
#define MSG_ANON_CANT_OVERWRITE "ʹ߲ܸдִļ"
#define MSG_DELE_FAILED "޷ɾ %s"
#define MSG_DELE_SUCCESS "ɾ %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "ûɾļ"
#define MSG_LOAD_TOO_HIGH "ʱ %3.2f ˸ʱǲ׼ʹء\nϴǿԵ"



#define MSG_OPEN_FAILURE "޷ %s"
#define MSG_OPEN_FAILURE2 "޷Ǹļ"
#define MSG_STAT_FAILURE "޷ҵļС"
#define MSG_STAT_FAILURE2 "޷ļǷ"
#define MSG_REST_TOO_LARGE_FOR_FILE "ļС %lldʱ¿ʼoffset %lld "
#define MSG_REST_RESET "offsetΪ 0 ¿ʼ"
#define MSG_NOT_REGULAR_FILE "ֻһļ"
#define MSG_NOT_MODERATED "ļʹϴ\nûбվԱ׼ء"


#define MSG_RATIO_DENIAL "Ǹϴ/ %u:%u \nĿǰϴ %llu Kb  %llu Kb\nϴһЩöȻٳء"



#define MSG_NO_MORE_TO_DOWNLOAD "û"
#define MSG_WINNER "ѡε"
#define MSG_KBYTES_LEFT "ʣ %.1f kbytesҪ"
#define MSG_ABORTED "ֹ"
#define MSG_DATA_WRITE_FAILED "дʱ"
#define MSG_DATA_READ_FAILED "Ӷȡʱ"
#define MSG_MMAP_FAILED "޷ļmapڴ"
#define MSG_WRITE_FAILED "дļʱ"
#define MSG_TRANSFER_RATE_M "%.3f  (Ŀǰ),ÿ %.2f Mbytes"
#define MSG_TRANSFER_RATE_K "%.3f  (Ŀǰ),ÿ %.2f Kbytes"
#define MSG_TRANSFER_RATE_B "%.3f  (Ŀǰ),ÿ %.2f bytes"
#define MSG_SPACE_FREE_M "%.1f Mbytes ʣӲ̿ռ"
#define MSG_SPACE_FREE_K "%f Kbytes ʣӲ̿ռ"
#define MSG_DOWNLOADED ""
#define MSG_REST_NOT_NUMERIC "RESTҪֲ"
#define MSG_REST_ASCII_STRICT "ASCIIģʽӦǱ 0"
#define MSG_REST_ASCII_WORKAROUND "¿ʼ %lldASCIIģʽ"
#define MSG_REST_SUCCESS "¿ʼ %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "õĿ¼"
#define MSG_SANITY_FILE_FAILURE "õļ: %s"
#define MSG_MKD_FAILURE "޷Ŀ¼"
#define MSG_MKD_SUCCESS "Ŀ¼OK"
#define MSG_RMD_FAILURE "޷ɾĿ¼"
#define MSG_RMD_SUCCESS "ɾĿ¼OK"
#define MSG_TIMESTAMP_FAILURE "޷ȡʱ"
#define MSG_MODE_ERROR "ֻ֧ASCIIbinaryģʽ"
#define MSG_CREATE_FAILURE "޷ļ"
#define MSG_ABRT_ONLY "ϴʱABRTΨһõ"
#define MSG_UPLOAD_PARTIAL "ϴ"
#define MSG_REMOVED "ɾ"
#define MSG_UPLOADED "ϴ"
#define MSG_GMTIME_FAILURE "޷ȡõʱ"
#define MSG_TYPE_8BIT_FAILURE "ֻ֧8-bit bytesڲʮǰ"
#define MSG_TYPE_UNKNOWN "δ֪TYPE"
#define MSG_TYPE_SUCCESS "TYPEĿǰ"
#define MSG_STRU_FAILURE "ֻ֧F(ile)"
#define MSG_MODE_FAILURE "ʹS(tream)ģʽ"
#define MSG_RENAME_ABORT "ֹ֮ǰĸ"
#define MSG_RENAME_RNFR_SUCCESS "RNFR - ļڣ׼Ŀĵ"
#define MSG_FILE_DOESNT_EXIST "Ǹļ"
#define MSG_RENAME_ALREADY_THERE "RENAMEʧ - ĿļѾ"
#define MSG_RENAME_NORNFR "RNTOǰҪRNFR"
#define MSG_RENAME_FAILURE "/ƶʧ"
#define MSG_RENAME_SUCCESS "ļ/ƶOK"
#define MSG_NO_SUPERSERVER "super-server (like tcpserver)ִpure-ftpd"
#define MSG_NO_FTP_ACCOUNT "޷ҵ'ftp'ʺ"
#define MSG_CONF_ERR "ô"
#define MSG_NO_VIRTUAL_FILE "ȱʹļ"
#define MSG_ILLEGAL_THROTTLING "ϷĽֵ"
#define MSG_ILLEGAL_TRUSTED_GID "Ϸchrootgid"
#define MSG_ILLEGAL_USER_LIMIT "Ϸʹ"
#define MSG_ILLEGAL_FACILITY "δ֪ļ¼ʩ"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "ЧLDAPļ"
#define MSG_ILLEGAL_LOAD_LIMIT "Ϸĸ"
#define MSG_ILLEGAL_PORTS_RANGE "ϷĶ˿ڷΧ"
#define MSG_ILLEGAL_LS_LIMITS "Ϸ'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "ʽʱϷǿIP"
#define MSG_ILLEGAL_RATIO "Ϸϴ/"
#define MSG_ILLEGAL_UID_LIMIT "Ϸuid"
#define MSG_ILLEGAL_OPTION "δ֪run-timeѡ"
#define MSG_LDAP_MISSING_BASE "LDAPļȱLDAPBaseDN"
#define MSG_LDAP_WRONG_PARMS "LDAP"
#define MSG_NEW_CONNECTION " %s "
#define MSG_WELCOME_TO "ӭ"
#define MSG_MAX_USERS "%lu ʹ(ֵ)Ѿ¼Ǹ"
#define MSG_NB_USERS "ǵ %d ʹߣɴ %d "
#define MSG_WELCOME_TIME "ڱʱ %02d:%02d˿ڣ %u"
#define MSG_ANONYMOUS_FTP_ONLY "ֻFTP"
#define MSG_RATIOS_EVERYONE "EVERYONEñ:"
#define MSG_RATIOS_ANONYMOUS "ʹ߹涨UL/DL:"
#define MSG_RATIOS_RULE "Ҫ %u Mb, ϴ %u Mb ĺö"
#define MSG_INFO_IDLE_M " %lu ûлߡ"
#define MSG_INFO_IDLE_S " %lu ûлߡ"
#define MSG_CANT_READ_FILE "Ǹ޷ȡ[%s]"
#define MSG_LS_TRUNCATED "ض̵ %u "
#define MSG_LS_SUCCESS "ܹ %u "
#define MSG_LOGOUT "ǳ."
#define MSG_AUTH_FAILED_LOG "ʹ[%s]֤ʧ"
#define MSG_ILLEGAL_UMASK "Чumask"
#define MSG_STANDALONE_FAILED "޷standalone server"
#define MSG_NO_ANONYMOUS_LOGIN "˽ϵͳ - ¼"
#define MSG_ANONYMOUS_ANY_PASSWORD "κ붼"
#define MSG_MAX_USERS_IP "̫ (%lu)  IP"
#define MSG_ACTIVE_DISABLED "ģʽر"
#define MSG_TRANSFER_SUCCESSFUL "ļOK"
#define MSG_NO_DISK_SPACE "Ӳ̱ - Ժϴ"
#define MSG_OUT_OF_MEMORY "ڴ治"
#define MSG_ILLEGAL_TRUSTED_IP "ϷIPַ"
#define MSG_NO_ASCII_RESUME "ASCIIشȫɾļ"
#define MSG_UNKNOWN_ALTLOG "δ֪ļ¼ʽ"
#define MSG_ACCOUNT_DISABLED "޷¼Ϊ[%s]: ʺŹر"
#define MSG_SQL_WRONG_PARMS "SQL"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "ЧSQLļ"
#define MSG_SQL_MISSING_SERVER "SQLļȱٷ趨"
#define MSG_SQL_DOWN "SQL server񵱵"
#define MSG_ILLEGAL_QUOTA "ЧĶ"
#define MSG_QUOTA_FILES "%llu ļʹ (%d%%) - Ȩ: %llu "
#define MSG_QUOTA_SIZE "%llu Kbytesʹ (%d%%) - Ȩ: %llu Kb"
#define MSG_QUOTA_EXCEEDED ": [%s] ᱻ"
#define MSG_AUTH_UNKNOWN "δ֪֤"
#define MSG_PDB_BROKEN "޷ȡindexed puredbļ(⵽ɸʽ) -  pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s Ǳ %s "
#define MSG_ALIASES_UNKNOWN "δ֪ı %s"
#define MSG_ALIASES_BROKEN_FILE "𻵵ıļ"
#define MSG_ALIASES_LIST "µıã"
#define MSG_PERUSER_MAX "޷ͬһʹ߳ %lu "
#define MSG_IPV6_OK "ⲿҲӭIPv6"
#define MSG_TLS_INFO "SSL/TLS:  %s with %s, %d λԪ"
#define MSG_TLS_WEAK "SSL/TLS: 벻"
#define MSG_TLS_NEEDED "Ǹ˷ʽӡ\n" \
    "ʹSSL/TLSİȫӡ"
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."

==> pure-ftpd-1.0.35.tar.bz2: pure-ftpd-1.0.35/src/messages_zh_cn.h <==
#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "ʱ"
#define MSG_CAPABILITIES "޷л"
#define MSG_CLIENT_CLOSED_CNX "û˹ر"
#define MSG_CLIENT_READ_ERR "û˶ȡ"
#define MSG_CANT_OPEN_CNX "޷"
#define MSG_CANT_CREATE_DATA_SOCKET "޷ݽӿ"
#define MSG_DEBUG_CLIENT_IS "û˵ַ"
#define MSG_SYNTAX_ERROR_IP "﷨IPַ"
#define MSG_PORT_SUCCESSFUL "PORTOK"
#define MSG_ONLY_IPV4V6 "֧IPv4IPv6 (1,2)"
#define MSG_ONLY_IPV4 "֧IPv4 (1)"
#define MSG_TIMEOUT_PARSER "ʱ - »üʱٶȿһ"
#define MSG_LINE_TOO_LONG "й"
#define MSG_LOG_OVERFLOW "ûҪл"
#define MSG_GOODBYE "ټϴ%llu%llu kbytes."
#define MSG_DEBUG_COMMAND ""
#define MSG_IS_YOUR_CURRENT_LOCATION "Ŀǰλ"
#define MSG_NOT_LOGGED_IN "δ¼"
#define MSG_AUTH_UNIMPLEMENTED "ȫδʵʩ"
#define MSG_NO_FILE_NAME "ļ"
#define MSG_NO_DIRECTORY_NAME "Ŀ¼"
#define MSG_NO_RESTART_POINT "¿ʼ"
#define MSG_ABOR_SUCCESS "ABOR OK"
#define MSG_MISSING_ARG "ȱٲ"
#define MSG_GARBAGE_FOUND "ֵõִ"
#define MSG_VALUE_TOO_LARGE "ֵ"
#define MSG_IDLE_TIME "ʱΪ %lu "
#define MSG_SITE_HELP "еSITEϿ"
#define MSG_BAD_CHMOD "ЧȨ"
#define MSG_UNKNOWN_EXTENSION "δ֪"
#define MSG_XDBG_OK "XDBGOKԼ %d"
#define MSG_UNKNOWN_COMMAND "δ֪"
#define MSG_TIMEOUT_NOOP "ʱ ( %lu ޲)"
#define MSG_TIMEOUT_DATA "ʱ ( %lu )"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Ѿ¼"
#define MSG_ANY_PASSWORD "κ붼"
#define MSG_ANONYMOUS_LOGGED "ʹߵ¼"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "ʹߵ¼FTP"
#define MSG_USER_OK "ʹ %s OK. Ҫ."
#define MSG_CANT_DO_TWICE "Ŀǰڼ䲻"
#define MSG_UNABLE_SECURE_ANON "޷ȫFTP"
#define MSG_BANDWIDTH_RESTRICTED "Ĵʹ"
#define MSG_NO_PASSWORD_NEEDED "κ붼"
#define MSG_NOTRUST "Ǹ޷"
#define MSG_WHOAREYOU "˭"
#define MSG_AUTH_FAILED "֤ʧܣǸ"
#define MSG_AUTH_TOOMANY "֤ʧ̫"
#define MSG_NO_HOMEDIR "ûмĿ¼ - ȡ"
#define MSG_NO_HOMEDIR2 "%s ڻ޷"
#define MSG_START_SLASH "ʼ /"
#define MSG_USER_GROUP_ACCESS "ʹ %s Ȩޣ"
#define MSG_FXP_SUPPORT "֧FXP"
#define MSG_RATIO " %u:%u (UL/DL) "
#define MSG_CHROOT_FAILED "޷趨ȫchroot() jail"
#define MSG_CURRENT_DIR_IS "OK. ĿǰĿ¼ %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. ĿǰƵĿ¼ %s"
#define MSG_IS_NOW_LOGGED_IN "%s ڵ¼"
#define MSG_CANT_CHANGE_DIR "޷Ŀ¼ %s"
#define MSG_PATH_TOO_LONG "·̫"
#define MSG_CANT_PASV "IPv6ʹPASVEPSV"
#define MSG_CANT_PASSIVE "޷ʽ"
#define MSG_PORTS_BUSY "бTCP portsæµ"
#define MSG_GETSOCKNAME_DATA "޷ʶ𱾻ݽӿ"
#define MSG_GETPEERNAME "޷ʶ𱾻ӿ"
#define MSG_INVALID_IP "ǸЧĵַ"
#define MSG_NO_EPSV "ʹ÷IPv6֧EPSVû"
#define MSG_BAD_PORT "Ǹ޷ӵ ports < 1024"
#define MSG_NO_FXP "Ҳܿӵ %s ( %s)"
#define MSG_FXP "FXP:  %s  %s"
#define MSG_NO_DATA_CONN ""
#define MSG_ACCEPT_FAILED "޷"
#define MSG_ACCEPT_SUCCESS ""
#define MSG_CNX_PORT_FAILED "޷ӵport %d"
#define MSG_CNX_PORT "ӵport %d"
#define MSG_ANON_CANT_MKD "Ǹ׼ʹ߽Ŀ¼"
#define MSG_ANON_CANT_RMD "Ǹ׼ʹɾĿ¼"
#define MSG_ANON_CANT_RENAME "׼ʹƶ/ļ"
#define MSG_ANON_CANT_CHANGE_PERMS "ʹ߲ܱȨ"
#define MSG_GLOB_NO_MEMORY "γ %s ʱڴ治"
#define MSG_PROBABLY_DENIED "(ζ \"ܾ\")"
#define MSG_GLOB_READ_ERROR "γ %s ʱȡ"
#define MSG_GLOB_NO_MATCH "ûзϵ %s  %s "
#define MSG_CHMOD_FAILED "ܱ %s Ȩ"
#define MSG_CHMOD_SUCCESS " %s Ȩѱ"
#define MSG_CHMOD_TOTAL_FAILURE "Ǹ޷κȨ"
#define MSG_ANON_CANT_DELETE "ʹ߲ɾļ"
#define MSG_ANON_CANT_OVERWRITE "ʹ߲ܸдִļ"
#define MSG_DELE_FAILED "޷ɾ %s"
#define MSG_DELE_SUCCESS "ɾ %s%s%s%s"
#define MSG_DELE_TOTAL_FAILURE "ûɾļ"
#define MSG_LOAD_TOO_HIGH "ʱ %3.2f ˸ʱǲ׼ʹء\nϴǿԵ"



#define MSG_OPEN_FAILURE "޷ %s"
#define MSG_OPEN_FAILURE2 "޷Ǹļ"
#define MSG_STAT_FAILURE "޷ҵļС"
#define MSG_STAT_FAILURE2 "޷ļǷ"
#define MSG_REST_TOO_LARGE_FOR_FILE "ļС %lldʱ¿ʼoffset %lld "
#define MSG_REST_RESET "offsetΪ 0 ¿ʼ"
#define MSG_NOT_REGULAR_FILE "ֻһļ"
#define MSG_NOT_MODERATED "ļʹϴ\nûбվԱ׼ء"


#define MSG_RATIO_DENIAL "Ǹϴ/ %u:%u \nĿǰϴ %llu Kb  %llu Kb\nϴһЩöȻٳء"



#define MSG_NO_MORE_TO_DOWNLOAD "û"
#define MSG_WINNER "ѡε"
#define MSG_KBYTES_LEFT "ʣ %.1f kbytesҪ"
#define MSG_ABORTED "ֹ"
#define MSG_DATA_WRITE_FAILED "дʱ"
#define MSG_DATA_READ_FAILED "Ӷȡʱ"
#define MSG_MMAP_FAILED "޷ļmapڴ"
#define MSG_WRITE_FAILED "дļʱ"
#define MSG_TRANSFER_RATE_M "%.3f  (Ŀǰ),ÿ %.2f Mbytes"
#define MSG_TRANSFER_RATE_K "%.3f  (Ŀǰ),ÿ %.2f Kbytes"
#define MSG_TRANSFER_RATE_B "%.3f  (Ŀǰ),ÿ %.2f bytes"
#define MSG_SPACE_FREE_M "%.1f Mbytes ʣӲ̿ռ"
#define MSG_SPACE_FREE_K "%f Kbytes ʣӲ̿ռ"
#define MSG_DOWNLOADED ""
#define MSG_REST_NOT_NUMERIC "RESTҪֲ"
#define MSG_REST_ASCII_STRICT "ASCIIģʽӦǱ 0"
#define MSG_REST_ASCII_WORKAROUND "¿ʼ %lldASCIIģʽ"
#define MSG_REST_SUCCESS "¿ʼ %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "õĿ¼"
#define MSG_SANITY_FILE_FAILURE "õļ: %s"
#define MSG_MKD_FAILURE "޷Ŀ¼"
#define MSG_MKD_SUCCESS "Ŀ¼OK"
#define MSG_RMD_FAILURE "޷ɾĿ¼"
#define MSG_RMD_SUCCESS "ɾĿ¼OK"
#define MSG_TIMESTAMP_FAILURE "޷ȡʱ"
#define MSG_MODE_ERROR "ֻ֧ASCIIbinaryģʽ"
#define MSG_CREATE_FAILURE "޷ļ"
#define MSG_ABRT_ONLY "ϴʱABRTΨһõ"
#define MSG_UPLOAD_PARTIAL "ϴ"
#define MSG_REMOVED "ɾ"
#define MSG_UPLOADED "ϴ"
#define MSG_GMTIME_FAILURE "޷ȡõʱ"
#define MSG_TYPE_8BIT_FAILURE "ֻ֧8-bit bytesڲʮǰ"
#define MSG_TYPE_UNKNOWN "δ֪TYPE"
#define MSG_TYPE_SUCCESS "TYPEĿǰ"
#define MSG_STRU_FAILURE "ֻ֧F(ile)"
#define MSG_MODE_FAILURE "ʹS(tream)ģʽ"
#define MSG_RENAME_ABORT "ֹ֮ǰĸ"
#define MSG_RENAME_RNFR_SUCCESS "RNFR - ļڣ׼Ŀĵ"
#define MSG_FILE_DOESNT_EXIST "Ǹļ"
#define MSG_RENAME_ALREADY_THERE "RENAMEʧ - ĿļѾ"
#define MSG_RENAME_NORNFR "RNTOǰҪRNFR"
#define MSG_RENAME_FAILURE "/ƶʧ"
#define MSG_RENAME_SUCCESS "ļ/ƶOK"
#define MSG_NO_SUPERSERVER "super-server (like tcpserver)ִpure-ftpd"
#define MSG_NO_FTP_ACCOUNT "޷ҵ'ftp'ʺ"
#define MSG_CONF_ERR "ô"
#define MSG_NO_VIRTUAL_FILE "ȱʹļ"
#define MSG_ILLEGAL_THROTTLING "ϷĽֵ"
#define MSG_ILLEGAL_TRUSTED_GID "Ϸchrootgid"
#define MSG_ILLEGAL_USER_LIMIT "Ϸʹ"
#define MSG_ILLEGAL_FACILITY "δ֪ļ¼ʩ"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "ЧLDAPļ"
#define MSG_ILLEGAL_LOAD_LIMIT "Ϸĸ"
#define MSG_ILLEGAL_PORTS_RANGE "ϷĶ˿ڷΧ"
#define MSG_ILLEGAL_LS_LIMITS "Ϸ'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "ʽʱϷǿIP"
#define MSG_ILLEGAL_RATIO "Ϸϴ/"
#define MSG_ILLEGAL_UID_LIMIT "Ϸuid"
#define MSG_ILLEGAL_OPTION "δ֪run-timeѡ"
#define MSG_LDAP_MISSING_BASE "LDAPļȱLDAPBaseDN"
#define MSG_LDAP_WRONG_PARMS "LDAP"
#define MSG_NEW_CONNECTION " %s "
#define MSG_WELCOME_TO "ӭ"
#define MSG_MAX_USERS "%lu ʹ(ֵ)Ѿ¼Ǹ"
#define MSG_NB_USERS "ǵ %u ʹߣɴ %u "
#define MSG_WELCOME_TIME "ڱʱ %02d:%02d˿ڣ %u"
#define MSG_ANONYMOUS_FTP_ONLY "ֻFTP"
#define MSG_RATIOS_EVERYONE "EVERYONEñ:"
#define MSG_RATIOS_ANONYMOUS "ʹ߹涨UL/DL:"
#define MSG_RATIOS_RULE "Ҫ %u Mb, ϴ %u Mb ĺö"
#define MSG_INFO_IDLE_M " %lu ûлߡ"
#define MSG_INFO_IDLE_S " %lu ûлߡ"
#define MSG_CANT_READ_FILE "Ǹ޷ȡ[%s]"
#define MSG_LS_TRUNCATED "ض̵ %u "
#define MSG_LS_SUCCESS "ܹ %u "
#define MSG_LOGOUT "ǳ."
#define MSG_AUTH_FAILED_LOG "ʹ[%s]֤ʧ"
#define MSG_ILLEGAL_UMASK "Чumask"
#define MSG_STANDALONE_FAILED "޷standalone server"
#define MSG_NO_ANONYMOUS_LOGIN "˽ϵͳ - ¼"
#define MSG_ANONYMOUS_ANY_PASSWORD "κ붼"
#define MSG_MAX_USERS_IP "̫ (%lu)  IP"
#define MSG_ACTIVE_DISABLED "ģʽر"
#define MSG_TRANSFER_SUCCESSFUL "ļOK"
#define MSG_NO_DISK_SPACE "Ӳ̱ - Ժϴ"
#define MSG_OUT_OF_MEMORY "ڴ治"
#define MSG_ILLEGAL_TRUSTED_IP "ϷIPַ"
#define MSG_NO_ASCII_RESUME "ASCIIشȫɾļ"
#define MSG_UNKNOWN_ALTLOG "δ֪ļ¼ʽ"
#define MSG_ACCOUNT_DISABLED "޷¼Ϊ[%s]: ʺŹر"
#define MSG_SQL_WRONG_PARMS "SQL"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "ЧSQLļ"
#define MSG_SQL_MISSING_SERVER "SQLļȱٷ趨"
#define MSG_SQL_DOWN "SQL server񵱵"
#define MSG_ILLEGAL_QUOTA "ЧĶ"
#define MSG_QUOTA_FILES "%llu ļʹ (%d%%) - Ȩ: %llu "
#define MSG_QUOTA_SIZE "%llu Kbytesʹ (%d%%) - Ȩ: %llu Kb"
#define MSG_QUOTA_EXCEEDED ": [%s] ᱻ"
#define MSG_AUTH_UNKNOWN "δ֪֤"
#define MSG_PDB_BROKEN "޷ȡindexed puredbļ(⵽ɸʽ) -  pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s Ǳ %s "
#define MSG_ALIASES_UNKNOWN "δ֪ı %s"
#define MSG_ALIASES_BROKEN_FILE "𻵵ıļ"
#define MSG_ALIASES_LIST "µıã"
#define MSG_PERUSER_MAX "޷ͬһʹ߳ %lu "
#define MSG_IPV6_OK "ⲿҲӭIPv6"
#define MSG_TLS_INFO "SSL/TLS:  %s with %s, %d λԪ"
#define MSG_TLS_WEAK "SSL/TLS: 벻"
#define MSG_TLS_NEEDED "Ǹ˷ʽӡ\n" \
    "ʹSSL/TLSİȫӡ"
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
